==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/EventSubscriptionFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link EventSubscription}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class EventSubscriptionFieldAttributes extends AbstractBeanAttributesDefinition{

    /** categoryId (Database column: CATEGORY_ID) */
    static public AttributeDefinition categoryId =
        new AttributeDefinition("categoryId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CATEGORY_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** configuration (Database column: CONFIGURATION) */
    static public AttributeDefinition configuration =
        new AttributeDefinition("configuration")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CONFIGURATION")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** isEnabled (Database column: IS_ENABLED) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(boolean.class);

    /** publisherId (Database column: PUBLISHER_ID) */
    static public AttributeDefinition publisherId =
        new AttributeDefinition("publisherId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("PUBLISHER_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** subscriberId (Database column: SUBSCRIBER_ID) */
    static public AttributeDefinition subscriberId =
        new AttributeDefinition("subscriberId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("SUBSCRIBER_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(categoryId.getName(),categoryId);
        map.put(configuration.getName(),configuration);
        map.put(configId.getName(),configId);
        map.put(id.getName(),id);
        map.put(isEnabled.getName(),isEnabled);
        map.put(publisherId.getName(),publisherId);
        map.put(subscriberId.getName(),subscriberId);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/EventSubscriptionFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link EventSubscription}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class EventSubscriptionFieldAttributes extends AbstractBeanAttributesDefinition{

    /** categoryId (Database column: CATEGORY_ID) */
    static public AttributeDefinition categoryId =
        new AttributeDefinition("categoryId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CATEGORY_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /** configuration (Database column: CONFIGURATION) */
    static public AttributeDefinition configuration =
        new AttributeDefinition("configuration")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CONFIGURATION")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** configId (Database column: CONFIG_ID) */
    static public AttributeDefinition configId =
        new AttributeDefinition("configId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("CONFIG_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** isEnabled (Database column: IS_ENABLED) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** publisherId (Database column: PUBLISHER_ID) */
    static public AttributeDefinition publisherId =
        new AttributeDefinition("publisherId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("PUBLISHER_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /** subscriberId (Database column: SUBSCRIBER_ID) */
    static public AttributeDefinition subscriberId =
        new AttributeDefinition("subscriberId")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("EVENT_SUBSCRIPTION")
                .setDatabaseId("SUBSCRIBER_ID")
                .setMandatory(false)
                .setMaxSize(255)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return "configId";
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(categoryId.getName(),categoryId);
        map.put(configuration.getName(),configuration);
        map.put(configId.getName(),configId);
        map.put(id.getName(),id);
        map.put(isEnabled.getName(),isEnabled);
        map.put(publisherId.getName(),publisherId);
        map.put(subscriberId.getName(),subscriberId);

        return map;
    }
}
